==> qt3d-opensource-src_5.5.1.orig.tar.xz: qt3d-opensource-src-5.5.1/tests/auto/render/renderviews/tst_renderviews.cpp <==
/****************************************************************************
**
** Copyright (C) 2015 Klaralvdalens Datakonsult AB (KDAB).
** Contact: http://www.qt-project.org/legal
**
** This file is part of the Qt3D module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL3$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see http://www.qt.io/terms-conditions. For further
** information use the contact form at http://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 3 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPLv3 included in the
** packaging of this file. Please review the following information to
** ensure the GNU Lesser General Public License version 3 requirements
** will be met: https://www.gnu.org/licenses/lgpl.html.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 2.0 or later as published by the Free
** Software Foundation and appearing in the file LICENSE.GPL included in
** the packaging of this file. Please review the following information to
** ensure the GNU General Public License version 2.0 requirements will be
** met: http://www.gnu.org/licenses/gpl-2.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/

#include <QtTest/QTest>
#include <private/renderview_p.h>
#include <private/qframeallocator_p.h>

class tst_RenderViews : public QObject
{
    Q_OBJECT
private Q_SLOTS:

    void checkRenderViewSizeFitsWithAllocator()
    {
        QVERIFY(sizeof(Qt3D::Render::RenderView) <= 128);
        QVERIFY(sizeof(Qt3D::Render::RenderView::InnerData) <= 128);
    }

    void testSort()
    {

    }

    void checkRenderViewDoesNotLeak()
    {
        // GIVEN
        Qt3D::QFrameAllocator allocator(128, 16, 128);
        Qt3D::Render::RenderView *rv = allocator.allocate<Qt3D::Render::RenderView>();
        rv->setAllocator(&allocator);

        // THEN
        QVERIFY(!allocator.isEmpty());

        // WHEN
        delete rv;

        // THEN
        QVERIFY(allocator.isEmpty());
    }

private:
};


QTEST_APPLESS_MAIN(tst_RenderViews)

#include "tst_renderviews.moc"

==> qt3d-opensource-src-5.6.2.tar.xz: qt3d-opensource-src-5.6.2/tests/auto/render/renderviews/tst_renderviews.cpp <==
/****************************************************************************
**
** Copyright (C) 2015 Klaralvdalens Datakonsult AB (KDAB).
** Contact: http://www.qt-project.org/legal
**
** This file is part of the Qt3D module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL3$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see http://www.qt.io/terms-conditions. For further
** information use the contact form at http://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 3 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPLv3 included in the
** packaging of this file. Please review the following information to
** ensure the GNU Lesser General Public License version 3 requirements
** will be met: https://www.gnu.org/licenses/lgpl.html.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 2.0 or later as published by the Free
** Software Foundation and appearing in the file LICENSE.GPL included in
** the packaging of this file. Please review the following information to
** ensure the GNU General Public License version 2.0 requirements will be
** met: http://www.gnu.org/licenses/gpl-2.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/

#include <QtTest/QTest>
#include <private/renderview_p.h>
#include <private/qframeallocator_p.h>
#include <private/qframeallocator_p_p.h>

class tst_RenderViews : public QObject
{
    Q_OBJECT
private Q_SLOTS:

    void checkRenderViewSizeFitsWithAllocator()
    {
        QVERIFY(sizeof(Qt3DRender::Render::RenderView) <= 128);
        QVERIFY(sizeof(Qt3DRender::Render::RenderView::InnerData) <= 128);
    }

    void testSort()
    {

    }

    void checkRenderViewDoesNotLeak()
    {
        // GIVEN
        Qt3DCore::QFrameAllocator allocator(128, 16, 128);
        Qt3DRender::Render::RenderView *rv = allocator.allocate<Qt3DRender::Render::RenderView>();
        rv->setAllocator(&allocator);

        // THEN
        QVERIFY(!allocator.isEmpty());

        // WHEN
        delete rv;

        // THEN
        QVERIFY(allocator.isEmpty());
    }

private:
};


QTEST_APPLESS_MAIN(tst_RenderViews)

#include "tst_renderviews.moc"
